@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # =============================================================================
-# Copyright (c) 2011 Tom Kralidis
+# Copyright (c) 2024 Tom Kralidis
 #
 # Authors : Tom Kralidis <tomkralidis@gmail.com>
 #
@@ -8,7 +8,9 @@
 # =============================================================================
 
 from io import BytesIO
+import logging
 from urllib.parse import urlencode
+
 from owslib.util import (
     testXMLValue,
     nspath_eval,
@@ -36,7 +38,7 @@ from owslib.feature.common import (
     AbstractContentMetadata,
 )
 from owslib.namespaces import Namespaces
-from owslib.util import log, openURL
+from owslib.util import openURL
 
 
 def get_namespaces():
@@ -46,54 +48,14 @@ def get_namespaces():
 
 namespaces = get_namespaces()
 
+LOGGER = logging.getLogger(__name__)
+
 
 class WebFeatureService_1_1_0(WebFeatureService_):
     """Abstraction for OGC Web Feature Service (WFS).
 
     Implements IWebFeatureService.
     """
-
-    def __new__(
-        self,
-        url,
-        version,
-        xml,
-        parse_remote_metadata=False,
-        timeout=30,
-        headers=None,
-        username=None,
-        password=None,
-        auth=None,
-    ):
-        """ overridden __new__ method
-
-        @type url: string
-        @param url: url of WFS capabilities document
-        @type xml: string
-        @param xml: elementtree object
-        @type parse_remote_metadata: boolean
-        @param parse_remote_metadata: whether to fully process MetadataURL elements
-        @param headers: HTTP headers to send with requests
-        @param timeout: time (in seconds) after which requests should timeout
-        @param username: service authentication username
-        @param password: service authentication password
-        @param auth: instance of owslib.util.Authentication
-        @return: initialized WebFeatureService_1_1_0 object
-        """
-        obj = object.__new__(self)
-        obj.__init__(
-            url,
-            version,
-            xml,
-            parse_remote_metadata,
-            timeout,
-            headers=headers,
-            username=username,
-            password=password,
-            auth=auth,
-        )
-        return obj
-
     def __getitem__(self, name):
         """ check contents dictionary to allow dict like access to service layers"""
         if name in list(self.__getattribute__("contents").keys()):
@@ -328,7 +290,7 @@ class WebFeatureService_1_1_0(WebFeatureService_):
                 request["outputFormat"] = outputFormat
 
             data = urlencode(request)
-            log.debug("Making request: %s?%s" % (base_url, data))
+            LOGGER.debug("Making request: %s?%s" % (base_url, data))
 
         elif method.lower() == "post":
             base_url, data = self.getPOSTGetFeatureRequest(
